@@ -2,7 +2,7 @@
 
 # Cross-Correlation with normalization set to default
 
-from scipy.signal import correlate
+from scipy.signal import convolve, correlate
 
 import numpy as np
 
@@ -15,7 +15,7 @@ def signal_correlation(in1, in2, norm=True):
     # Default output is set to normalized
     if norm:
         sPow = np.sqrt(np.sum(arrS*arrS.conj()))
-        lPow = np.sqrt(np.convolve(arrL*arrL.conj(), np.ones(len(arrS)), mode='full'))*sPow
+        lPow = np.sqrt(convolve(arrL*arrL.conj(), np.ones(len(arrS)), mode='full'))*sPow
         outArr = outArr/lPow
     return outArr
 
